@@ -3,7 +3,7 @@ from improviser.Progressions import *
 
 class Block:
 
-	progressions = Jazz.african_flower
+	progressions = Contemporary.reincarnatie
 	
 	bpm = 200
 	resolution = 8
