@@ -17,13 +17,18 @@ if __name__ == '__main__':
 	parser = OptionParser()
 	parser.add_option("-b", "--bpm", dest="bpm", type="int",
 		help="Set the bpm to start with.")
+	parser.add_option("-d", "--duration", dest="duration", type="int",
+		help="Set the number of times the progression should be repeated.")
 	parser.add_option("-f", "--frontend", dest="frontend", 
-		metavar="F", help="Choose front-end [none, pygame]")
+		metavar="F", help="Choose front-end [blocks, lines]")
 	parser.add_option("-k", "--key", dest="key",
 		help="Set the key to start in.")
 	parser.add_option("-q", "--quiet", action="store_false",
 		dest="verbose")
-	parser.add_option("-v", "--verbose", action="store_true", dest="verbose", default=True)
+	parser.add_option("-v", "--verbose", action="store_true", 
+		dest="verbose", default=True)
+	parser.add_option("-w", "--wildness", type="float", dest="wild",
+		help="Floating point number indicating wildness")
 
 	(options, args) = parser.parse_args()
 
@@ -31,9 +36,15 @@ if __name__ == '__main__':
 	visual = None
 	block = Block()
 
-	if options.frontend == "pygame":
+	if options.frontend == "blocks":
 		from Visualizations import PygameBlockVisualization
 		visual = PygameBlockVisualization(400,400)
+	elif options.frontend == "lines":
+		from Visualizations import PygameLineVisualization
+		visual = PygameLineVisualization(400,400)
+	elif options.frontend == "mixed":
+		from Visualizations import PygameMixedVisualizations
+		visual = PygameMixedVisualizations(400,400)
 
 	if options.key != None:
 		if notes.is_valid_note(options.key):
@@ -45,6 +56,11 @@ if __name__ == '__main__':
 	if options.bpm != None:
 		block.bpm = options.bpm
 
+	if options.duration != None:
+		block.duration = options.duration
+
+	if options.wild != None:
+		block.wildness = options.wild
 
 	if not fluidsynth.init_fluidsynth():
 		print "No running fluidsynth server found at port 9800."
